@@ -1,12 +1,8 @@
 #!/usr/bin/env python
 """Manage multiple git, mercurial, svn repositories from a YAML / JSON file.
 
-vcspull
-~~~~~~~
-
 :copyright: Copyright 2013-2018 Tony Narlock.
 :license: MIT, see LICENSE for details
-
 """
 # Set default logging handler to avoid "No handler found" warnings.
 import logging
