@@ -1,8 +1,5 @@
 """Log utilities for formatting CLI output in vcspull.
 
-vcspull.log
-~~~~~~~~~~~
-
 This module containers special formatters for processing the additional context
 information from :class:`libvcs.base.RepoLoggingAdapter`.
 
@@ -167,7 +164,7 @@ class DebugLogFormatter(LogFormatter):
         ]
 
         tpl = "".join(
-            reset + levelname + asctime + name + module_funcName + lineno + reset
+            reset + levelname + asctime + name + module_funcName + lineno + reset,
         )
 
         return tpl
@@ -179,7 +176,7 @@ class RepoLogFormatter(LogFormatter):
     def template(self, record: logging.LogRecord) -> str:
         """Template for logging vcs bin name, along with a contextual hint."""
         record.message = "".join(
-            [Fore.MAGENTA, Style.BRIGHT, record.message, Fore.RESET, Style.RESET_ALL]
+            [Fore.MAGENTA, Style.BRIGHT, record.message, Fore.RESET, Style.RESET_ALL],
         )
         return "{}|{}| {}({}) {}".format(
             Fore.GREEN + Style.DIM,
